<?php

namespace Slovocast\Infrastructure\Database;

class ConnectionPoolConfig
{
    const DEFAULT_WAIT_TIMEOUT = 60;
    const DEFAULT_TOTAL_CONNECTIONS = 10;

    public function __construct(
        public readonly string $username,
        public readonly string $password,
        public readonly string $database,
        public readonly string $host,
        protected int $port = 3306,
        protected int $poolWaitTimeout = self::DEFAULT_WAIT_TIMEOUT,
        protected int $totalConnections = self::DEFAULT_TOTAL_CONNECTIONS
    ) { }

    public function getPort(): int
    {
        return $this->port;
    }

    public function getPoolWaitTimeout(): int
    {
        return $this->poolWaitTimeout;
    }

    public function getTotalConnections(): int
    {
        return $this->totalConnections;
    }

    public function getDsnString(): string
    {
        return sprintf(
            "%s:%s@%s/%s",
            rawurlencode($this->username),
            rawurlencode($this->password),
            $this->host,
            $this->database
        );
    }
}
